==========================
How It Works
==========================

Workflow
________

.. image:: images/plant_embasi_classes.png
           :width: 800

.. image:: images/plant_flow.png
           :width: 800

.. image:: images/plant_embasi_devroadmap.png
           :width: 800
